@@ -24,11 +24,10 @@ from pymc3.exceptions import SamplingError
 from pymc3.model import Point, modelcontext
 from pymc3.step_methods import arraystep, step_sizes
 from pymc3.step_methods.hmc import integration
+from pymc3.step_methods.hmc.quadpotential import QuadPotentialDiagAdapt, quad_potential
 from pymc3.theanof import floatX, inputvars
 from pymc3.tuning import guess_scaling
 
-from .quadpotential import QuadPotentialDiagAdapt, quad_potential
-
 logger = logging.getLogger("pymc3")
 
 HMCStepData = namedtuple("HMCStepData", "end, accept_stat, divergence_info, stats")
