@@ -27,8 +27,7 @@ import pymc3 as pm
 from pymc3 import Deterministic, Potential
 from pymc3.distributions import HalfCauchy, Normal, transforms
 from pymc3.model import ValueGradFunction
-
-from .helpers import select_by_precision
+from pymc3.tests.helpers import select_by_precision
 
 
 class NewModel(pm.Model):
@@ -168,13 +167,13 @@ class TestObserved:
 
 class TestTheanoConfig:
     def test_set_testval_raise(self):
-        with theano.configparser.change_flags(compute_test_value="off"):
+        with theano.config.change_flags(compute_test_value="off"):
             with pm.Model():
                 assert theano.config.compute_test_value == "raise"
             assert theano.config.compute_test_value == "off"
 
     def test_nested(self):
-        with theano.configparser.change_flags(compute_test_value="off"):
+        with theano.config.change_flags(compute_test_value="off"):
             with pm.Model(theano_config={"compute_test_value": "ignore"}):
                 assert theano.config.compute_test_value == "ignore"
                 with pm.Model(theano_config={"compute_test_value": "warn"}):
@@ -195,7 +194,13 @@ def test_matrix_multiplication():
         rv_det = pm.Deterministic("rv_det", matrix @ rv_rv)
         det_rv = pm.Deterministic("det_rv", rv_rv @ transformed)
 
-        posterior = pm.sample(10, tune=0, compute_convergence_checks=False, progressbar=False)
+        posterior = pm.sample(
+            10,
+            tune=0,
+            compute_convergence_checks=False,
+            progressbar=False,
+            return_inferencedata=False,
+        )
         decimal = select_by_precision(7, 5)
         for point in posterior.points():
             npt.assert_almost_equal(
@@ -367,6 +372,34 @@ class TestValueGradFunction(unittest.TestCase):
 
         assert m["x2_missing"].type == gf._extra_vars_shared["x2_missing"].type
 
+    def test_theano_switch_broadcast_edge_cases(self):
+        # Tests against two subtle issues related to a previous bug in Theano where tt.switch would not
+        # always broadcast tensors with single values https://github.com/pymc-devs/aesara/issues/270
+
+        # Known issue 1: https://github.com/pymc-devs/pymc3/issues/4389
+        data = np.zeros(10)
+        with pm.Model() as m:
+            p = pm.Beta("p", 1, 1)
+            obs = pm.Bernoulli("obs", p=p, observed=data)
+        # Assert logp is correct
+        npt.assert_allclose(
+            obs.logp(m.test_point),
+            np.log(0.5) * 10,
+        )
+
+        # Known issue 2: https://github.com/pymc-devs/pymc3/issues/4417
+        # fmt: off
+        data = np.array([
+            1.35202174, -0.83690274, 1.11175166, 1.29000367, 0.21282749,
+            0.84430966, 0.24841369, 0.81803141, 0.20550244, -0.45016253,
+        ])
+        # fmt: on
+        with pm.Model() as m:
+            mu = pm.Normal("mu", 0, 5)
+            obs = pm.TruncatedNormal("obs", mu=mu, sigma=1, lower=-1, upper=2, observed=data)
+        # Assert dlogp is correct
+        npt.assert_allclose(m.dlogp([mu])({"mu": 0}), 2.499424682024436, rtol=1e-5)
+
 
 def test_multiple_observed_rv():
     "Test previously buggy MultiObservedRV comparison code."
